/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.apache.catalina.util;


public class TomcatCSS {

    public static final String TOMCAT_CSS =
        "body {font-family:Tahoma,Arial,sans-serif;} " +
        "h1, h2, h3, b {color:white;background-color:#525D76;} " +
        "h1 {font-size:22px;} " +
        "h2 {font-size:16px;} " +
        "h3 {font-size:14px;} " +
        "p {font-size:12px;} " +
        "a {color:black;} " +
        ".line {height:1px;background-color:#525D76;border:none;}";

}
